from datamemorys.core.common import *
SYCM_DATAS={
    "sycm_brands_hotsales":SYCMDATA_BRANDS_HOTSALES,
    "sycm_brands_hotsearch":SYCMDATA_BRANDS_HOTSEARCH,
    "sycm_shops_hotsales":SYCMDATA_SHOPS_HOTSALES,
    "sycm_shops_hotsearch":SYCMDATA_SHOPS_HOTSEARCH,
    "sycm_items_hotsales":SYCMDATA_ITEMS_HOTSALES,
    "sycm_items_hotsearch":SYCMDATA_ITEMS_HOTSEARCH,
    "sycm_items_hotpurposes":SYCMDATA_ITEMS_PURPOSES,
    "databank_aipl_trendding":DATABANKDATA_AIPL_TRENDDING,
    "sycm_shopsources_monitor":SYCMDATA_SHOPSOURCES_MONITOR
}
