

SYCMDATA_BRANDS_HOTSALES="http://127.0.0.1:50667/download/1/{}/7/6"
SYCMDATA_BRANDS_HOTSEARCH="http://127.0.0.1:50667/download/1/{}/7/7"
SYCMDATA_SHOPS_HOTSALES="http://127.0.0.1:50667/download/1/{}/4/1"
SYCMDATA_SHOPS_HOTSEARCH="http://127.0.0.1:50667/download/1/{}/4/2"
SYCMDATA_ITEMS_HOTSALES="http://127.0.0.1:50667/download/1/{}/5/3"
SYCMDATA_ITEMS_HOTSEARCH="http://127.0.0.1:50667/download/1/{}/5/4"
SYCMDATA_ITEMS_PURPOSES="http://127.0.0.1:50667/download/1/{}/5/5"
SYCMDATA_SHOPSOURCES_MONITOR="http://127.0.0.1:50667/download/1/{}/15/48"
SYCMDATA_SHOPS_MONITORTRENDDING="http://127.0.0.1:50667/download/1/{}/4/57"
DATABANKDATA_AIPL_TRENDDING="http://127.0.0.1:50667/download/1/{}/2/27"